summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvasrectangle_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvasrectangle_imp.h')
-rw-r--r--kjsembed/qtbindings/qcanvasrectangle_imp.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kjsembed/qtbindings/qcanvasrectangle_imp.h b/kjsembed/qtbindings/qcanvasrectangle_imp.h
index 1e141fe2..3daf243a 100644
--- a/kjsembed/qtbindings/qcanvasrectangle_imp.h
+++ b/kjsembed/qtbindings/qcanvasrectangle_imp.h
@@ -9,7 +9,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
-class TQCanvasRectangle;
+class TTQCanvasRectangle;
/**
* Namespace containing the KJSEmbed library.
@@ -17,11 +17,11 @@ class TQCanvasRectangle;
namespace KJSEmbed {
/**
* Wrapper class for TQCanvasRectangle methods.
*
* @author Richard Moore, rich@kde.org
*/
-class QCanvasRectangleImp : public JSProxyImp
+class TQCanvasRectangleImp : public JSProxyImp
{
public:
/** Enumerates the constructors supported by this class. */
@@ -47,8 +47,8 @@ public:
Method_Last = -1
};
- QCanvasRectangleImp( KJS::ExecState *exec, int id, bool constructor=false );
- ~QCanvasRectangleImp();
+ TQCanvasRectangleImp( KJS::ExecState *exec, int id, bool constructor=false );
+ ~TQCanvasRectangleImp();
/**
* Adds the static bindings for this class to the specified Object. The
@@ -62,15 +62,15 @@ public:
*/
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TQCanvasRectangle *toQCanvasRectangle( KJS::Object &object );
+ static TTQCanvasRectangle *toTQCanvasRectangle( KJS::Object &object );
//
// Constructors implemented by this class.
//
- KJS::Object QCanvasRectangle_1( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QCanvasRectangle_2( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QCanvasRectangle_3( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCanvasRectangle_1( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCanvasRectangle_2( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCanvasRectangle_3( KJS::ExecState *exec, const KJS::List &args );
//
// Methods implemented by this class.
@@ -102,7 +102,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TQCanvasRectangle *instance; // Temp
+ TTQCanvasRectangle *instance; // Temp
int id;
bool cons;
};
@@ -17,11 +17,11 @@ class TQCanvasRectangle;
namespace KJSEmbed {
/**
- * Wrapper class for TQCanvasRectangle methods.
+ * Wrapper class for TTQCanvasRectangle methods.
*
* @author Richard Moore, rich@kde.org